pub struct KostenblattEvent(pub AckForwardEvent);Expand description
Workflow-specific event newtype for one of the six ack-forward process families.
Wraps AckForwardEvent and returns a workflow-specific prefix from
EventPayload::event_type so events from different ack-forward
workflows are distinguishable in projections and the event log.
Tuple Fields
0: AckForwardEventTrait Implementations
Sourceimpl Clone for KostenblattEvent
impl Clone for KostenblattEvent
Sourcefn clone(&self) -> KostenblattEvent
fn clone(&self) -> KostenblattEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KostenblattEvent
impl Debug for KostenblattEvent
Sourceimpl<'de> Deserialize<'de> for KostenblattEvent
impl<'de> Deserialize<'de> for KostenblattEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EventPayload for KostenblattEvent
impl EventPayload for KostenblattEvent
Sourcefn event_type(&self) -> &'static str
fn event_type(&self) -> &'static str
A stable, unique name for this event variant. Read more
Sourcefn schema_version(&self) -> u32
fn schema_version(&self) -> u32
Schema version of this event’s payload layout. Read more
Sourceimpl From<AckForwardEvent> for KostenblattEvent
impl From<AckForwardEvent> for KostenblattEvent
Sourcefn from(e: AckForwardEvent) -> Self
fn from(e: AckForwardEvent) -> Self
Converts to this type from the input type.
Sourceimpl From<KostenblattEvent> for AckForwardEvent
impl From<KostenblattEvent> for AckForwardEvent
Sourcefn from(e: KostenblattEvent) -> AckForwardEvent
fn from(e: KostenblattEvent) -> AckForwardEvent
Converts to this type from the input type.