pub struct NetzengpassEvent(pub AckForwardEvent);Expand description
Workflow-specific event newtype for one of the six ack-forward process families.
Wraps AckForwardEvent and returns a workflow-specific prefix from
EventPayload::event_type so events from different ack-forward
workflows are distinguishable in projections and the event log.
Tuple Fields
0: AckForwardEventTrait Implementations
Sourceimpl Clone for NetzengpassEvent
impl Clone for NetzengpassEvent
Sourcefn clone(&self) -> NetzengpassEvent
fn clone(&self) -> NetzengpassEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NetzengpassEvent
impl Debug for NetzengpassEvent
Sourceimpl<'de> Deserialize<'de> for NetzengpassEvent
impl<'de> Deserialize<'de> for NetzengpassEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl EventPayload for NetzengpassEvent
impl EventPayload for NetzengpassEvent
Sourcefn event_type(&self) -> &'static str
fn event_type(&self) -> &'static str
A stable, unique name for this event variant. Read more
Sourcefn schema_version(&self) -> u32
fn schema_version(&self) -> u32
Schema version of this event’s payload layout. Read more
Sourceimpl From<AckForwardEvent> for NetzengpassEvent
impl From<AckForwardEvent> for NetzengpassEvent
Sourcefn from(e: AckForwardEvent) -> Self
fn from(e: AckForwardEvent) -> Self
Converts to this type from the input type.
Sourceimpl From<NetzengpassEvent> for AckForwardEvent
impl From<NetzengpassEvent> for AckForwardEvent
Sourcefn from(e: NetzengpassEvent) -> AckForwardEvent
fn from(e: NetzengpassEvent) -> AckForwardEvent
Converts to this type from the input type.